json5: A Python implementation of the JSON5 data format.
========================================================

Description
-----------

A Python implementation of the JSON5 data format.

License
-------

Apache

Upstream Contact
----------------

https://pypi.org/project/json5/

